import { Component, signal, effect, ViewChild, ElementRef, AfterViewChecked } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { TestCompletion } from '../../../../lib/completion';
import { animate, style, transition, trigger } from '@angular/animations';

interface ChatMessage {
  role: 'user' | 'assistant';
  content: string;
  timestamp?: Date;
}

interface HistoryItem {
  id: string;
  preview: string;
  time: Date;
  messages: ChatMessage[];
}

@Component({
  selector: 'app-chat',
  standalone: true,
  imports: [CommonModule, FormsModule],
  templateUrl: './page-text-response.html',
  styleUrls: ['./page-text-response.scss'],
  animations: [
    trigger('messageAnimation', [
      transition(':enter', [
        style({ opacity: 0, transform: 'translateY(10px)' }),
        animate('200ms ease-out', style({ opacity: 1, transform: 'translateY(0)' }))
      ])
    ]),
    trigger('panelAnimation', [
      transition(':enter', [
        style({ transform: 'translateX(100%)' }),
        animate('250ms ease-out', style({ transform: 'translateX(0)' }))
      ]),
      transition(':leave', [
        animate('200ms ease-in', style({ transform: 'translateX(100%)' }))
      ])
    ])
  ]
})
export class PageTextResponse implements AfterViewChecked {
  userInput = '';
  isLoading = signal(false);
  errorMessage = signal<string | null>(null);
  messageList = signal<ChatMessage[]>([]);
  showHistoryPanel = false;
  inputFocused = false;
  historyItems: HistoryItem[] = [];
  
  @ViewChild('messagesContainer') private messagesContainer!: ElementRef;
  @ViewChild('messageInput') private messageInput!: ElementRef;

  constructor() {
    // 模拟历史数据
    this.historyItems = Array.from({ length: 5 }, (_, i) => ({
      id: `hist-${i}`,
      preview: `Test conversation ${i + 1} about AI assistants...`,
      time: new Date(Date.now() - (i * 24 * 60 * 60 * 1000)),
      messages: []
    }));

    // 添加欢迎消息
    effect(() => {
      if (this.messageList().length === 0) {
        setTimeout(() => {
          this.addWelcomeMessage();
        }, 500); // 延迟显示以获得更好的加载体验
      }
    });
  }

  ngAfterViewChecked() {
    this.scrollToBottom();
  }

  private scrollToBottom(): void {
    try {
      this.messagesContainer.nativeElement.scrollTop = this.messagesContainer.nativeElement.scrollHeight;
    } catch(err) { }
  }

  private addWelcomeMessage() {
    this.messageList.update(messages => [
      ...messages,
      {
        role: 'assistant',
        content: 'Hello! I\'m your AI assistant. How can I help you today?',
        timestamp: new Date()
      }
    ]);
  }

  isNewGroup(index: number): boolean {
    if (index === 0) return false;
    const prevMsg = this.messageList()[index - 1];
    const currentMsg = this.messageList()[index];
    
    // 如果超过5分钟或角色变化，则视为新组
    const timeDiff = (currentMsg.timestamp!.getTime() - prevMsg.timestamp!.getTime()) / (1000 * 60);
    return timeDiff > 5 || prevMsg.role !== currentMsg.role;
  }

  toggleHistory() {
    this.showHistoryPanel = !this.showHistoryPanel;
  }

  async sendMessage() {
    if (!this.userInput.trim()) return;

    const userMessage: ChatMessage = {
      role: 'user',
      content: this.userInput,
      timestamp: new Date()
    };

    // 添加用户消息
    this.messageList.update(messages => [...messages, userMessage]);
    this.userInput = '';
    this.isLoading.set(true);
    this.errorMessage.set(null);

    // 聚焦输入框以保持键盘打开（移动端）
    setTimeout(() => {
      this.messageInput.nativeElement.focus();
    }, 100);

    try {
      const completion = new TestCompletion(this.messageList());
      
      let assistantMessageIndex = this.messageList().length;
      this.messageList.update(messages => [...messages, { 
        role: 'assistant', 
        content: '', 
        timestamp: new Date() 
      }]);

      await completion.sendMessage(null, (content) => {
        this.messageList.update(messages => {
          const updated = [...messages];
          updated[assistantMessageIndex].content = content;
          return updated;
        });
      });
    } catch (error) {
      console.error('Error sending message:', error);
      this.errorMessage.set('Failed to get response. Please try again.');
    } finally {
      this.isLoading.set(false);
    }
  }

  handleKeyPress(event: KeyboardEvent) {
    if (event.key === 'Enter' && !event.shiftKey) {
      event.preventDefault();
      this.sendMessage();
    }
  }

  copyMessage(content: string) {
    navigator.clipboard.writeText(content).then(() => {
      // 可以在这里添加复制成功的反馈
      console.log('Message copied to clipboard');
    });
  }

  openFilePicker() {
    // 实现文件选择逻辑
    console.log('Open file picker');
  }
}